@@ -49,6 +49,7 @@ from untanglepyut.UntangleSequenceDiagram import createOglSDInstances
 
 @dataclass
 class ProjectInformation:
+    fileName: str = cast(str, None)
     version:  str = cast(str, None)
     codePath: str = cast(str, None)
 
@@ -143,6 +144,8 @@ class UnTangler(BaseUnTangle):
         xmlString:   str     = self.getRawXml(fqFileName=fqFileName)
         self.untangleXml(xmlString=xmlString)
 
+        self._projectInformation.fileName = fqFileName
+
     def untangleXml(self, xmlString: str):
         """
         Untangle the input Xml string to Ogl
@@ -185,7 +188,7 @@ class UnTangler(BaseUnTangle):
                 linkableOglObjects = self._buildDictionary(document=document)
                 document.oglLinks  = self._untangleOglLinks.graphicLinksToOglLinks(pyutDocument, linkableOglObjects=linkableOglObjects)
             else:
-                assert False, f'Unknown document type: f{document.documentType}'
+                assert False, f'Unknown document type: {document.documentType}'
 
     def getRawXml(self, fqFileName: str) -> str:
         """
